# Using the VL53L1X distance sensor
import board, time, adafruit_vl53l1x, math, neopixel, digitalio, random
from audiopwmio import PWMAudioOut as AudioOut
from audiomp3 import MP3Decoder
from adafruit_debouncer import Debouncer
from adafruit_led_animation.color import(
    AMBER,
    AQUA,
    BLACK,
    BLUE,
    CYAN,
    GOLD,
    GREEN,
    JADE,
    MAGENTA,
    OLD_LACE,
    ORANGE,
    PINK,
    PURPLE,
    RED,
    TEAL,
    WHITE,
    YELLOW,
    RAINBOW
)

ic2 = board.I2C()
distance_sensor = adafruit_vl53l1x.VL53L1X(ic2)
distance_sensor.start_ranging()

pixels_pin = board.NEOPIXEL
pixels_num_of_lights = 10
pixels = neopixel.NeoPixel(pixels_pin, pixels_num_of_lights, brightness = 0.2, auto_write = True)

strip_pin = board.A3
strip_num_of_lights = 30
strip = neopixel.NeoPixel(strip_pin, strip_num_of_lights, brightness = 0.2, auto_write = True)

button_A_input = digitalio.DigitalInOut(board.BUTTON_A)
button_A_input.direction = digitalio.Direction.INPUT
button_A_input.pull = digitalio.Pull.DOWN
button_A = Debouncer(button_A_input)

button_B_input = digitalio.DigitalInOut(board.BUTTON_B)
button_B_input.direction = digitalio.Direction.INPUT
button_B_input.pull = digitalio.Pull.DOWN
button_B = Debouncer(button_B_input)

speaker = digitalio.DigitalInOut(board.SPEAKER_ENABLE)
speaker.direction = digitalio.Direction.OUTPUT
speaker.value = True
audio = AudioOut(board.SPEAKER)
audio_clips = ["curry.mp3", "dagger.mp3", "dame.mp3", "ice-trae.mp3", "KOBE!.mp3", "no-regard.mp3", "ray_allen.mp3", "red-hot.mp3", "carmelo.mp3", "kidding-me.mp3", "for-the-lead.mp3"]
court_sounds = ["court-sound.mp3", "ball-so-hard.mp3"]
mp3 = open("cheer.mp3", "rb")
decoder = MP3Decoder(mp3)

score = 0

def shot_clock():
    strip.fill(RED)
    for i in range(29, -1, -1):
        strip[i] = BLACK
        time.sleep(1.01)
    strip.fill(RED)
    pixels.fill(RED)

"""
def play_mp3(filename, shot_made):
    decoder.file = open(filename, "rb")
    audio.play(decoder)
    if not shot_made:
        while audio.playing:
            if distance_sensor.data_ready:
                distance = distance_sensor.distance
                print("Distance: {0}cm, {1:.2f}in".format(distance, distance*0.394))
                time.sleep(0.01)
                if distance < 3.5:
                    pixels.fill(GREEN)
                    audio.pause()
                #score = score + 1
                #if score % 3 == 0:
                    #random_num = random.randint(0, 10)
                    #play_mp3(audio_clips[random_num])
                #else:
                    play_mp3("cheer.mp3", True)
                    pixels.fill(BLACK)
                    audio.resume()
"""

def play_mp3_basic(filename):
    decoder.file = open(filename, "rb")
    audio.play(decoder)
    while audio.playing:
        if distance_sensor.data_ready:
            distance = distance_sensor.distance
            print("Distance: {0}cm, {1:.2f}in".format(distance, distance*0.394))
            time.sleep(0.01)
            if distance < 3.3:
                pixels.fill(GREEN)
                time.sleep(1.0)
                pixels.fill(BLACK)

def play_mp3_basic_button_b(filename):
    decoder.file = open(filename, "rb")
    audio.play(decoder)
    while audio.playing:
        pixels.fill(GREEN)
    pixels.fill(BLACK)

def play_mp3(filename):
    decoder.file = open(filename, "rb")
    audio.play(decoder)
    while audio.playing:
        pass


strip.fill(BLACK)
pixels.fill(BLACK)

while True:
    button_A.update()
    button_B.update()
    if button_A.fell:
        random_num = random.randint(0, 1)
        play_mp3_basic(court_sounds[random_num])
        #strip.fill(RED)
        pixels.fill(RED)
        play_mp3("shot-clock.mp3")
        pixels.fill(BLACK)
        #strip.fill(BLACK)
    if button_B.fell:
        score = 0
        while True:
            button_B.update()
            if button_B.fell:
                print(score)
                play_mp3("you-scored.mp3")
                if score < 20:
                    play_mp3(str(score) + ".mp3")
                elif score < 100:
                    x = 0
                    while not score % 10 == 0:
                        score = score - 1
                        x = x + 1
                    play_mp3(str(score) + ".mp3")
                    if not x == 0:
                        play_mp3(str(x) + ".mp3")
                else:
                    play_mp3("a-ton-of.mp3")
                if score == 1:
                    play_mp3("point.mp3")
                else:
                    play_mp3("points.mp3")
                play_mp3("in-that-shoot-around.mp3")
                break
            if distance_sensor.data_ready:
                distance = distance_sensor.distance
                print("Distance: {0}cm, {1:.2f}in".format(distance, distance*0.394))
                time.sleep(0.01)
                if distance < 3.3:
                    score += 1
                    if score % 3 == 0:
                        random_num = random.randint(0,10)
                        play_mp3_basic_button_b(audio_clips[random_num])
                    else:
                        play_mp3_basic_button_b("cheer.mp3")
